pub fn unwrap_socketaddr(addr: SocketAddr) -> Result<SocketAddrV4, Fail>Expand description
Brief
Since IPv6 is not supported, this method simply unwraps a SocketAddr into a SocketAddrV4 or returns an error indicating the address family is not supported. This method should be removed when IPv6 support is added; see https://github.com/microsoft/demikernel/issues/935